@@ -1,3 +1,4 @@
+from . import doc_fifos
 from . import export
 from . import lookup
 from . import list as list_cmd
@@ -5,6 +6,7 @@ from . import documentation
 from . import build_clueweb_warc_indexes
 
 COMMANDS = {
+	'doc_fifos': doc_fifos.main,
     'export': export.main,
     'lookup': lookup.main,
     'list': list_cmd.main,
