@@ -34,11 +34,18 @@ class TrecQrel(NamedTuple):
     relevance: int
     iteration: str
 
+class TrecPrel(NamedTuple):
+    query_id: str
+    doc_id: str
+    relevance: int
+    method: int
+    iprob: float
+
 # Default content tags from Anserini's TrecCollection
 CONTENT_TAGS = 'TEXT HEADLINE TITLE HL HEAD TTL DD DATE LP LEADPARA'.split()
 
 class TrecDocs(BaseDocs):
-    def __init__(self, docs_dlc, encoding=None, path_globs=None, content_tags=CONTENT_TAGS, parser='BS4', namespace=None):
+    def __init__(self, docs_dlc, encoding=None, path_globs=None, content_tags=CONTENT_TAGS, parser='BS4', namespace=None, lang=None):
         self._docs_dlc = docs_dlc
         self._encoding = encoding
         self._path_globs = path_globs
@@ -52,6 +59,7 @@ class TrecDocs(BaseDocs):
             'text': GenericDoc,
         }[parser]
         self._docs_namespace = namespace
+        self._docs_lang = lang
 
     def docs_path(self):
         return self._docs_dlc.path()
@@ -155,6 +163,9 @@ class TrecDocs(BaseDocs):
     def docs_namespace(self):
         return self._docs_namespace
 
+    def docs_lang(self):
+        return self._docs_lang
+
 
 DEFAULT_QTYPE_MAP = {
     '<num> *(Number:)?': 'query_id',
@@ -163,12 +174,14 @@ DEFAULT_QTYPE_MAP = {
     '<narr> *(Narrative:)?': 'narrative'
 }
 class TrecQueries(BaseQueries):
-    def __init__(self, queries_dlc, qtype=TrecQuery, qtype_map=None, encoding=None, namespace=None):
+    def __init__(self, queries_dlc, qtype=TrecQuery, qtype_map=None, encoding=None, namespace=None, lang=None, remove_tags=('</title>',)):
         self._queries_dlc = queries_dlc
         self._qtype = qtype
         self._qtype_map = qtype_map or DEFAULT_QTYPE_MAP
         self._encoding = encoding
         self._queries_namespace = namespace
+        self._queries_lang = lang
+        self._remove_tags = remove_tags
 
     def queries_path(self):
         return self._queries_dlc.path()
@@ -180,6 +193,8 @@ class TrecQueries(BaseQueries):
             for line in f:
                 if line.startswith('</top>'):
                     assert len(fields) == len(self._qtype._fields), fields
+                    for tag in self._remove_tags:
+                        fields = {k: v.replace(tag, '') for k, v in fields.items()}
                     yield self._qtype(*(fields[f].strip() for f in self._qtype._fields))
                     fields, reading = {}, None
                 match_any = False
@@ -199,15 +214,19 @@ class TrecQueries(BaseQueries):
     def queries_namespace(self):
         return self._queries_namespace
 
+    def queries_lang(self):
+        return self._queries_lang
+
 
 class TrecXmlQueries(BaseQueries):
-    def __init__(self, queries_dlc, qtype=TrecQuery, qtype_map=None, encoding=None, subtopics_key='subtopics', namespace=None):
+    def __init__(self, queries_dlc, qtype=TrecQuery, qtype_map=None, encoding=None, subtopics_key='subtopics', namespace=None, lang=None):
         self._queries_dlc = queries_dlc
         self._qtype = qtype
         self._qtype_map = qtype_map or {f: f for f in qtype._fields}
         self._encoding = encoding
         self._subtopics_key = subtopics_key
         self._queries_namespace = namespace
+        self._queries_lang = lang
 
     def queries_path(self):
         return self._queries_dlc.path()
@@ -245,12 +264,16 @@ class TrecXmlQueries(BaseQueries):
     def queries_namespace(self):
         return self._queries_namespace
 
+    def queries_lang(self):
+        return self._queries_lang
+
 
 class TrecColonQueries(BaseQueries):
-    def __init__(self, queries_dlc, encoding=None, namespace=None):
+    def __init__(self, queries_dlc, encoding=None, namespace=None, lang=None):
         self._queries_dlc = queries_dlc
         self._encoding = encoding
         self._queries_namespace = namespace
+        self._queries_lang = lang
 
     def queries_iter(self):
         with self._queries_dlc.stream() as f:
@@ -269,6 +292,9 @@ class TrecColonQueries(BaseQueries):
     def queries_namespace(self):
         return self._queries_namespace
 
+    def queries_lang(self):
+        return self._queries_lang
+
 
 class TrecQrels(BaseQrels):
     def __init__(self, qrels_dlc, qrels_defs):
@@ -297,6 +323,23 @@ class TrecQrels(BaseQrels):
         return self._qrels_defs
 
 
+class TrecPrels(TrecQrels):
+    def qrels_iter(self):
+        with self._qrels_dlc.stream() as f:
+            f = codecs.getreader('utf8')(f)
+            for line in f:
+                if line == '\n':
+                    continue # ignore blank lines
+                cols = line.rstrip().split()
+                if len(cols) != 5:
+                    raise RuntimeError(f'expected 5 columns, got {len(cols)}')
+                qid, did, rel, method, iprob = cols
+                yield TrecPrel(qid, did, int(rel), int(method), float(iprob))
+
+    def qrels_cls(self):
+        return TrecPrel
+
+
 class TrecScoredDocs(BaseScoredDocs):
     def __init__(self, scoreddocs_dlc):
         self._scoreddocs_dlc = scoreddocs_dlc
